# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2021-01-12

### Added

- Add liquidfill and wordcloud extensions

### Changed

- Use streamlit-component-lib package
- Extracted demo examples to their own repo

## [0.1.0] - 2020-07-06

### Added

- Initial release of `st_echarts` and `st_pyecharts`
